SafeRowConvenience extension
Methods
-
parseDateTime(
String key) → DateTime -
Available on SafeRow<
Parses a SQLite integer (epoch) into a Dart DateTime.Record> , provided by the SafeRowConvenience extension -
parseDateTimeOptional(
String key) → DateTime? -
Available on SafeRow<
Parses an optional SQLite integer (epoch) into a Dart DateTime.Record> , provided by the SafeRowConvenience extension -
parseEnumByName<
T extends Enum> (String key, Iterable< T> values) → T -
Available on SafeRow<
Parses a SQLite String into a Dart Enum using its name.Record> , provided by the SafeRowConvenience extension -
parseEnumByNameOptional<
T extends Enum> (String key, Iterable< T> values) → T? -
Available on SafeRow<
Parses an optional SQLite String into a Dart Enum using its name.Record> , provided by the SafeRowConvenience extension