SQL class

Wrapper for a value to be used in a SQL statement.

Primarily used with UpdateCommand or InsertCommand to distinguish between "omit this field" (plain null) and "set this field to NULL" (SQL(null)).

Constructors

SQL(Object? value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited