Context for read-only operations.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
P, R extends Record> (Query< P, R> query, [P? params]) → Future<SafeRow< R> > - Fetches exactly one row. Throws if no row is found.
-
getAll<
P, R extends Record> (Query< P, R> query, [P? params]) → Future<SafeResultSet< R> > - Fetches all rows matching the query.
-
getOptional<
P, R extends Record> (Query< P, R> query, [P? params]) → Future<SafeRow< R> ?> - Fetches an optional row. Returns null if not found.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited