Query<P, R extends Record> class
P defines the input Parameter type.
R defines the expected output Record type (serves as a token for custom linting).
Constructors
- Query(String sql, {dynamic params, required ResultSchema schema})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- params → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → ResultSchema
-
final
- sql → String
-
final
Methods
-
apply(
P? p) → (String, Map< String, Object?> ) - Returns the SQL string and the mapped parameters for this command.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
static<
R extends Record> (String sql, {required ResultSchema schema}) → Query< void, R> - Factory for static queries.