SQL class
Wrapper for a value to be used in a SQL statement.
Primarily used with UpdateCommand or InsertCommand to distinguish between
"omit this field" (plain null) and "set this field to NULL" (SQL(null)).
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited